==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/HuntOwnerArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.HuntOwnerArgs.builder
import com.pulumi.azurenative.securityinsights.kotlin.enums.OwnerType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Describes a user that the hunt is assigned to
 * @property assignedTo The name of the user the hunt is assigned to.
 * @property email The email of the user the hunt is assigned to.
 * @property objectId The object id of the user the hunt is assigned to.
 * @property ownerType The type of the owner the hunt is assigned to.
 * @property userPrincipalName The user principal name of the user the hunt is assigned to.
 */
public data class HuntOwnerArgs(
    public val assignedTo: Output<String>? = null,
    public val email: Output<String>? = null,
    public val objectId: Output<String>? = null,
    public val ownerType: Output<Either<String, OwnerType>>? = null,
    public val userPrincipalName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.HuntOwnerArgs> {
    override fun toJava(): com.pulumi.azurenative.securityinsights.inputs.HuntOwnerArgs =
        com.pulumi.azurenative.securityinsights.inputs.HuntOwnerArgs.builder()
            .assignedTo(assignedTo?.applyValue({ args0 -> args0 }))
            .email(email?.applyValue({ args0 -> args0 }))
            .objectId(objectId?.applyValue({ args0 -> args0 }))
            .ownerType(
                ownerType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .userPrincipalName(userPrincipalName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HuntOwnerArgs].
 */
@PulumiTagMarker
public class HuntOwnerArgsBuilder internal constructor() {
    private var assignedTo: Output<String>? = null

    private var email: Output<String>? = null

    private var objectId: Output<String>? = null

    private var ownerType: Output<Either<String, OwnerType>>? = null

    private var userPrincipalName: Output<String>? = null

    /**
     * @param value The name of the user the hunt is assigned to.
     */
    @JvmName("vimgdmxvkpmknrem")
    public suspend fun assignedTo(`value`: Output<String>) {
        this.assignedTo = value
    }

    /**
     * @param value The email of the user the hunt is assigned to.
     */
    @JvmName("kgsrglsgeloldmla")
    public suspend fun email(`value`: Output<String>) {
        this.email = value
    }

    /**
     * @param value The object id of the user the hunt is assigned to.
     */
    @JvmName("qvbtpsymmpnufssf")
    public suspend fun objectId(`value`: Output<String>) {
        this.objectId = value
    }

    /**
     * @param value The type of the owner the hunt is assigned to.
     */
    @JvmName("rifbkxhgckdcsrip")
    public suspend fun ownerType(`value`: Output<Either<String, OwnerType>>) {
        this.ownerType = value
    }

    /**
     * @param value The user principal name of the user the hunt is assigned to.
     */
    @JvmName("fejmjadfrikqjsiy")
    public suspend fun userPrincipalName(`value`: Output<String>) {
        this.userPrincipalName = value
    }

    /**
     * @param value The name of the user the hunt is assigned to.
     */
    @JvmName("mobididfykjmqrad")
    public suspend fun assignedTo(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.assignedTo = mapped
    }

    /**
     * @param value The email of the user the hunt is assigned to.
     */
    @JvmName("ilqyddhfqcutwdjv")
    public suspend fun email(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.email = mapped
    }

    /**
     * @param value The object id of the user the hunt is assigned to.
     */
    @JvmName("ajyvxeygjhyvoofn")
    public suspend fun objectId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.objectId = mapped
    }

    /**
     * @param value The type of the owner the hunt is assigned to.
     */
    @JvmName("tfwawwcrghegtuaw")
    public suspend fun ownerType(`value`: Either<String, OwnerType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ownerType = mapped
    }

    /**
     * @param value The type of the owner the hunt is assigned to.
     */
    @JvmName("jurcdpfsnkvlpjpx")
    public fun ownerType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, OwnerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ownerType = mapped
    }

    /**
     * @param value The type of the owner the hunt is assigned to.
     */
    @JvmName("gcvaxxrsyhvkbqoq")
    public fun ownerType(`value`: OwnerType) {
        val toBeMapped = Either.ofRight<String, OwnerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ownerType = mapped
    }

    /**
     * @param value The user principal name of the user the hunt is assigned to.
     */
    @JvmName("glqgsotdowvilgyv")
    public suspend fun userPrincipalName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userPrincipalName = mapped
    }

    internal fun build(): HuntOwnerArgs = HuntOwnerArgs(
        assignedTo = assignedTo,
        email = email,
        objectId = objectId,
        ownerType = ownerType,
        userPrincipalName = userPrincipalName,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/HuntOwnerArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.HuntOwnerArgs.builder
import com.pulumi.azurenative.securityinsights.kotlin.enums.OwnerType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Describes a user that the hunt is assigned to
 * @property assignedTo The name of the user the hunt is assigned to.
 * @property email The email of the user the hunt is assigned to.
 * @property objectId The object id of the user the hunt is assigned to.
 * @property ownerType The type of the owner the hunt is assigned to.
 * @property userPrincipalName The user principal name of the user the hunt is assigned to.
 */
public data class HuntOwnerArgs(
    public val assignedTo: Output<String>? = null,
    public val email: Output<String>? = null,
    public val objectId: Output<String>? = null,
    public val ownerType: Output<Either<String, OwnerType>>? = null,
    public val userPrincipalName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.HuntOwnerArgs> {
    override fun toJava(): com.pulumi.azurenative.securityinsights.inputs.HuntOwnerArgs =
        com.pulumi.azurenative.securityinsights.inputs.HuntOwnerArgs.builder()
            .assignedTo(assignedTo?.applyValue({ args0 -> args0 }))
            .email(email?.applyValue({ args0 -> args0 }))
            .objectId(objectId?.applyValue({ args0 -> args0 }))
            .ownerType(
                ownerType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .userPrincipalName(userPrincipalName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HuntOwnerArgs].
 */
@PulumiTagMarker
public class HuntOwnerArgsBuilder internal constructor() {
    private var assignedTo: Output<String>? = null

    private var email: Output<String>? = null

    private var objectId: Output<String>? = null

    private var ownerType: Output<Either<String, OwnerType>>? = null

    private var userPrincipalName: Output<String>? = null

    /**
     * @param value The name of the user the hunt is assigned to.
     */
    @JvmName("hoflfitknvvrkxtw")
    public suspend fun assignedTo(`value`: Output<String>) {
        this.assignedTo = value
    }

    /**
     * @param value The email of the user the hunt is assigned to.
     */
    @JvmName("ecfdqoqoarjoeofd")
    public suspend fun email(`value`: Output<String>) {
        this.email = value
    }

    /**
     * @param value The object id of the user the hunt is assigned to.
     */
    @JvmName("asqklphkxdhhdwfu")
    public suspend fun objectId(`value`: Output<String>) {
        this.objectId = value
    }

    /**
     * @param value The type of the owner the hunt is assigned to.
     */
    @JvmName("frrbnikdabbdsjsq")
    public suspend fun ownerType(`value`: Output<Either<String, OwnerType>>) {
        this.ownerType = value
    }

    /**
     * @param value The user principal name of the user the hunt is assigned to.
     */
    @JvmName("sjggkeggniqtebmu")
    public suspend fun userPrincipalName(`value`: Output<String>) {
        this.userPrincipalName = value
    }

    /**
     * @param value The name of the user the hunt is assigned to.
     */
    @JvmName("rvayvedlxlqtrwvw")
    public suspend fun assignedTo(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.assignedTo = mapped
    }

    /**
     * @param value The email of the user the hunt is assigned to.
     */
    @JvmName("wxfbonbilfwbkmju")
    public suspend fun email(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.email = mapped
    }

    /**
     * @param value The object id of the user the hunt is assigned to.
     */
    @JvmName("mbycfdbcsnqqtoua")
    public suspend fun objectId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.objectId = mapped
    }

    /**
     * @param value The type of the owner the hunt is assigned to.
     */
    @JvmName("iktwixvjbabkoofj")
    public suspend fun ownerType(`value`: Either<String, OwnerType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ownerType = mapped
    }

    /**
     * @param value The type of the owner the hunt is assigned to.
     */
    @JvmName("cyvjiogekqbwaduc")
    public fun ownerType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, OwnerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ownerType = mapped
    }

    /**
     * @param value The type of the owner the hunt is assigned to.
     */
    @JvmName("aiagkgwialnxpclj")
    public fun ownerType(`value`: OwnerType) {
        val toBeMapped = Either.ofRight<String, OwnerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ownerType = mapped
    }

    /**
     * @param value The user principal name of the user the hunt is assigned to.
     */
    @JvmName("cxcasmkbtrexfjxi")
    public suspend fun userPrincipalName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userPrincipalName = mapped
    }

    internal fun build(): HuntOwnerArgs = HuntOwnerArgs(
        assignedTo = assignedTo,
        email = email,
        objectId = objectId,
        ownerType = ownerType,
        userPrincipalName = userPrincipalName,
    )
}
